/*
  Project:      POVColor
  File:         aboutdlg.cpp
  Purpose:      About dialog implementation
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>
#include <wx/log.h>
#include <wx/intl.h>
#include <wx/string.h>
#include <wx/dialog.h>
#include <wx/sizer.h>
#include <wx/textctrl.h>
#include <wx/msgdlg.h>
#include <wx/utils.h>
#include <wx/stattext.h>
#include <wx/statbmp.h>
#include <wx/button.h>
#include <wx/bitmap.h>
#include <wx/panel.h>
#include <wx/hyperlink.h>
#include <wx/notebook.h>
#include <wx/stdpaths.h>
#include <wx/filename.h>

#include "app.h"
#include "art.h"
#include "aboutdlg.h"


// About dialog
//-----------------------------------------------------------------------------
enum
{
    ID_DETAILS = wxID_HIGHEST + 100,
};


// ctor
AboutDialog::AboutDialog(wxWindow* parent)
{
    // Create the dialog
    if(wxDialog::Create(parent, wxID_ANY, _("About")) == false)
    {
        return;
    }
    
    // Create the dialog items
    CreateWidgets(); 
  
    // Center
    CenterOnParent(wxBOTH);
}

// dtor
AboutDialog::~AboutDialog()
{
}

// Show extended details
void AboutDialog::OnDetails(wxCommandEvent& evt)
{
    if(evt.GetId() == ID_DETAILS)
    {
        AboutDetailsDialog dlg(this);
    
        dlg.ShowModal();
    }
}

// Create interface
void AboutDialog::CreateWidgets()
{
    wxBusyCursor busy;

    // Top sizer
    wxBoxSizer *topSizer = new wxBoxSizer(wxVERTICAL);
    
    // Icon on left, text on right
    wxBoxSizer* aboutSizer = new wxBoxSizer(wxHORIZONTAL);
  
#if wxUSE_STATBMP
    wxBitmap bmp(Art::GetBitmap(wxT("mainicon")));
    if(bmp.IsOk())
    {
        aboutSizer->Add(new wxStaticBitmap(this, wxID_ANY, bmp),
            wxSizerFlags().Border(wxRIGHT));
    }
#endif
  
    // Text on the right
    wxBoxSizer* textSizer = new wxBoxSizer(wxVERTICAL);
    
    textSizer->Add(new wxStaticText(this, wxID_ANY, wxT("POVColor " APP_VERSION)),
        wxSizerFlags(0).Left().Border(wxBOTTOM));
        
    textSizer->Add(new wxStaticText(this, wxID_ANY, wxT(APP_DESC)),
        wxSizerFlags(0).Left().Border(wxBOTTOM));
        
    textSizer->Add(new wxStaticText(this, wxID_ANY, wxT(APP_COPYRIGHT)),
        wxSizerFlags(0).Left().Border(wxBOTTOM));
        
    textSizer->Add(new wxHyperlinkCtrl(this, wxID_ANY, wxT(APP_WEBSITE), wxT(APP_WEBSITE)),
        wxSizerFlags(0).Left().DoubleBorder(wxBOTTOM));

    textSizer->Add(new wxButton(this, ID_DETAILS, _("Details")),
        wxSizerFlags(0).Center().DoubleBorder(wxBOTTOM));

        
    aboutSizer->Add(textSizer, wxSizerFlags(1).Expand());

    // Put it on the top
    topSizer->Add(aboutSizer, wxSizerFlags(1).Expand().Border());
    
    // Buttons
    wxSizer* buttons = CreateSeparatedButtonSizer(wxOK);
    if(buttons)
    {
        topSizer->Add(buttons, wxSizerFlags(0).Expand().DoubleBorder(wxLEFT | wxRIGHT | wxBOTTOM));
    }
    
        
    SetSizerAndFit(topSizer);
}

BEGIN_EVENT_TABLE(AboutDialog, wxDialog)
    EVT_BUTTON(ID_DETAILS, AboutDialog::OnDetails)
END_EVENT_TABLE()


// About details dialog
//-----------------------------------------------------------------------------

// ctor
AboutDetailsDialog::AboutDetailsDialog(wxWindow* parent)
{
    // Create the dialog
    if(wxDialog::Create(parent, wxID_ANY, _("About")) == false)
    {
        return;
    }
    
    // Create the dialog items
    CreateWidgets(); 
    
    // Center
    CenterOnParent(wxBOTH);
}

// dtor
AboutDetailsDialog::~AboutDetailsDialog()
{
}

// Create interface
void AboutDetailsDialog::CreateWidgets()
{
    wxBusyCursor busy;

    // Top sizer
    wxBoxSizer *topSizer = new wxBoxSizer(wxVERTICAL);
    
    // Create notebook
    wxNotebook *book = new wxNotebook(this, wxID_ANY);
    topSizer->Add(book, wxSizerFlags(1).Expand().DoubleBorder());
    
    // Load pages
    AddTextPage(book, wxT("License"), wxT("license.txt"));
    AddTextPage(book, wxT("GPL"), wxT("copying.txt"));
    AddTextPage(book, wxT("Authors"), wxT("authors.txt"));
    AddTextPage(book, wxT("Credits"), wxT("credits.txt"));
    
    // Buttons
    wxSizer* buttons = CreateSeparatedButtonSizer(wxOK);
    if(buttons)
    {
        topSizer->Add(buttons, wxSizerFlags(0).Expand().DoubleBorder(wxLEFT | wxRIGHT | wxBOTTOM));
    }

    SetSizerAndFit(topSizer);
}

// Add a page from a file under the help directory
// Like AddTextPage(book, "GPL", "COPYING")
void AboutDetailsDialog::AddTextPage(wxNotebook* book, const wxString& title, const wxString& file)
{
    // First get the filename and be sure it exists
    wxString docfile = wxGetApp().GetStandardDocFile(file);
    
    // Create panel and text control
    wxPanel* panel = new wxPanel(book);
    wxTextCtrl* text = new wxTextCtrl(panel, wxID_ANY, wxEmptyString, wxDefaultPosition,
        wxSize(600, 400), wxTE_MULTILINE | wxTE_READONLY | wxTE_DONTWRAP | wxBORDER_SUNKEN);
        
    // Use fixed pitch font
    wxFont curFont = text->GetFont();
    wxFont fixedFont(curFont.GetPointSize(), wxFONTFAMILY_MODERN, curFont.GetStyle(), curFont.GetWeight());
    if(fixedFont.IsOk())
        text->SetFont(fixedFont);
        
    // Sizer
    wxBoxSizer* sizer = new wxBoxSizer(wxVERTICAL);
    
    sizer->Add(text, wxSizerFlags(1).Expand().Border());
    
    panel->SetSizer(sizer);
    
    // Add the page
    book->AddPage(panel, title);
    
    // Load the contents
    if(wxFileName::FileExists(docfile))
    {
        text->LoadFile(docfile);
    }
    else
    {
        text->SetValue(wxString::Format(_("Unable to load text file: %s"), docfile.c_str()));    
    }
}


