/*
  Project:      POVColor
  File:         app.h
  Purpose:      Application object
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __POVCOLOR_APP_H__
#define __POVCOLOR_APP_H__


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>
#include <wx/app.h>
#include <wx/string.h>
#include <wx/arrstr.h>

// Foward declarations
class WXDLLIMPEXP_BASE wxConfigBase;
class WXDLLIMPEXP_BASE wxCmdLineParser;

class Options;


// PovColor - Application class
//-----------------------------------------------------------------------------
class PovColor : public wxApp
{
public:
    // ctor/dtor
    PovColor();
    ~PovColor();

    // Init and exit the program
    bool OnInit();
    int OnExit();

    // Command line
    void OnInitCmdLine(wxCmdLineParser& parser);
    bool OnCmdLineParsed(wxCmdLineParser& parser);

    // Paths
    wxString GetAppDataDir();
    wxString GetUserDataDir();
    wxString GetPixmapsDir();
    wxString GetHelpFile();
    wxString GetStandardDocFile(const wxString& file);
    wxString GetConfigFile();

    void CreateUserDirs();

    // Config and options
    wxConfigBase* GetConfig() { return m_config; }
    Options& GetOptions() { return *m_options; }

    // Helpers until wxWidgets 3
    #if !wxCHECK_VERSION(3, 0, 0)
        void SetAppDisplayName(const wxString& name) { m_appDispName = name; }
        const wxString& GetAppDisplayName() const { return m_appDispName; }

        void SetVendorDisplayName(const wxString& name) { m_venDispName = name; }
        const wxString& GetVendorDisplayName() const { return m_venDispName; }
    #endif
  
private:
    // No copy or assign
    PovColor(const PovColor& copy);
    PovColor& operator=(const PovColor& copy);

    #if !wxCHECK_VERSION(3, 0, 0)
        wxString m_appDispName;
        wxString m_venDispName;
    #endif

    // Config and options
    wxConfigBase* m_config;
    Options* m_options;

    // Paths
    wxString m_appDataDir;
    wxString m_userDataDir;

    // Files to open
    wxArrayString m_files;
};
  
DECLARE_APP(PovColor);  

#endif // Include once header


