/*
  File:         art.h
  Purpose:      Simple file-based art provider
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would
     be appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not
     be misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.
*/


#ifndef __BAVII_WX_ART_H__
#define __BAVII_WX_ART_H__


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include <wx/defs.h>
#include <wx/string.h>
#include <wx/artprov.h>
#include <wx/iconbndl.h>
#include <wx/dynarray.h>


// Art
//-----------------------------------------------------------------------------

// Available sizes
struct ArtSize
{
    ArtSize(int _min, int _max, const wxString& _dir) :
        min(_min), max(_max), dir(_dir)
    {
    }

    int min;
    int max;
    wxString dir;
};

WX_DECLARE_OBJARRAY(ArtSize, ArrayArtSize);

// Art class
class Art : public wxArtProvider
{
public:
    // Ctor/dtor
    Art();
    ~Art();

    // Get a bitmap or icon bundle
    static wxIcon GetIcon(const wxArtID& id, const wxArtClient& client = wxART_OTHER,
        const wxSize& = wxDefaultSize);
    static wxBitmap GetBitmap(const wxArtID& id, const wxArtClient& client = wxART_OTHER,
        const wxSize& = wxDefaultSize);
    static wxIconBundle GetIconBundle(const wxArtID& id, const wxArtClient& client = wxART_OTHER);

    // Set the base directory
    void SetDirectory(const wxString& dir)
    {
        m_directory = dir;
    }

    // Add a size directory
    void AddSize(int min, int max, const wxString& dir)
    {
        m_sizes.Add(ArtSize(min, max, dir));
    }

    // Add an extension
    void AddExt(const wxString& ext)
    {
        m_extensions.Add(ext);
    }

protected:
    // Create a bitmap
    wxBitmap CreateBitmap(const wxArtID& id, const wxArtClient& client, const wxSize& size);

    // Create an icon bundle
    wxIconBundle CreateIconBundle(const wxArtID& id, const wxArtClient& client);

private:
    // No copy/assign
    Art(const Art& copy);
    Art& operator=(const Art& rhs);

    // Function to fetch an image if possible
    wxBitmap FetchBitmap(const wxString& name, const wxString& sizeDir = wxEmptyString);
    wxIcon FetchIcon(const wxString& name, const wxString& sizeDir = wxEmptyString);

    // Information
    wxString m_directory;
    ArrayArtSize m_sizes;
    wxArrayString m_extensions;
};


#endif // Include once wrapper



