/*
  Project:      POVColor
  File:         widgets.cpp
  Purpose:      Implementation of custom widgets
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>
#include <wx/dcclient.h>
#include <wx/dcbuffer.h>

#include "color.h"
#include "colorcell.h"
#include "colorconv.h"
#include "util.h"


// ColorCellWidget - A simple color cell widget
//-----------------------------------------------------------------------------

// Events
const wxEventType EVENT_COLORCELL_SELECTED = wxNewEventType();
const wxEventType EVENT_COLORCELL_ALTSELECTED = wxNewEventType();

ColorCellEvent::ColorCellEvent(wxEventType type, wxWindowID id, const Color& color) :
        wxCommandEvent(type, id), m_color(color)
{
}

ColorCellEvent::ColorCellEvent(const ColorCellEvent& copy) :
        wxCommandEvent(copy), m_color(copy.m_color)
{
}

ColorCellEvent::~ColorCellEvent()
{
}



// The color cell widget
ColorCellWidget::ColorCellWidget(wxWindow* parent,
                                 wxWindowID id,
                                 const wxPoint& pos,
                                 const wxSize& size)
{
    wxControl::Create(parent, id, pos, size, wxBORDER_SUNKEN);
    SetBackgroundStyle(wxBG_STYLE_CUSTOM);
    SetMinSize(size);
}


ColorCellWidget::~ColorCellWidget()
{
}

// Set the color
void ColorCellWidget::SetColor(const Color& color)
{
    m_color = color;
    Refresh();
    Update();
}

// Left mouse down
void ColorCellWidget::OnLeftDown(wxMouseEvent& WXUNUSED(evt))
{
    ColorCellEvent cevt(EVENT_COLORCELL_SELECTED, GetId(), m_color);
    cevt.SetEventObject(this);

    GetParent()->ProcessEvent(cevt);
}

void ColorCellWidget::OnRightDown(wxMouseEvent& WXUNUSED(evt))
{
    ColorCellEvent cevt(EVENT_COLORCELL_ALTSELECTED, GetId(), m_color);
    cevt.SetEventObject(this);

    GetParent()->ProcessEvent(cevt);
}

void ColorCellWidget::OnPaint(wxPaintEvent& WXUNUSED(evt))
{
    wxAutoBufferedPaintDC dc(this);

    ColorItem item(m_color);
    item.Draw(dc, GetClientRect());
}

BEGIN_EVENT_TABLE(ColorCellWidget, wxControl)
    EVT_LEFT_DOWN(ColorCellWidget::OnLeftDown)
    EVT_RIGHT_DOWN(ColorCellWidget::OnRightDown)
    EVT_PAINT(ColorCellWidget::OnPaint)
END_EVENT_TABLE()





