/*
  Project:      POVColor
  File:         widgets.h
  Purpose:      Some custom widgets for the application
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __POVCOLOR_WIDGETS_H__
#define __POVCOLOR_WIDGETS_H__


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>
#include <wx/control.h>

#include "color.h"


// ColorCellWidget - A simple color cell widget
//-----------------------------------------------------------------------------

// Events for a color cell
extern const wxEventType EVENT_COLORCELL_SELECTED;
extern const wxEventType EVENT_COLORCELL_ALTSELECTED;

class ColorCellEvent : public wxCommandEvent
{
public:
    ColorCellEvent(wxEventType type, wxWindowID id, const Color& color);
    ColorCellEvent(const ColorCellEvent& copy);

    ~ColorCellEvent();

    wxEvent* Clone() const { return new ColorCellEvent(*this); }

    const Color& GetColor() const { return m_color; }

private:
    Color m_color;
};

typedef void (wxEvtHandler::*ColorCellEventFunction)(ColorCellEvent&);

#define ColorCellEventHandler(func) \
    (wxObjectEventFunction)(wxEventFunction)(wxCommandEventFunction) \
    wxStaticCastEvent(ColorCellEventFunction, &func)

#define EVT_COLORCELL_SELECTED(id, fn) \
    DECLARE_EVENT_TABLE_ENTRY(EVENT_COLORCELL_SELECTED, id, wxID_ANY, \
    ColorCellEventHandler(fn), (wxObject*)NULL),

#define EVT_COLORCELL_ALTSELECTED(id, fn) \
    DECLARE_EVENT_TABLE_ENTRY(EVENT_COLORCELL_ALTSELECTED, id, wxID_ANY, \
    ColorCellEventHandler(fn), (wxObject*)NULL),
 

// Color cell widget
class ColorCellWidget : public wxControl
{
public:
    // Constructor
    ColorCellWidget(wxWindow* parent,
                    wxWindowID id,
                    const wxPoint& pos = wxDefaultPosition,
                    const wxSize& size = wxDefaultSize);
    // Destructor
    ~ColorCellWidget();

    // Set the color
    void SetColor(const Color& color);

    // Get color
    const Color& GetColor() const { return m_color; }

    // Events
    void OnLeftDown(wxMouseEvent& evt);
    void OnRightDown(wxMouseEvent& evt);
    void OnPaint(wxPaintEvent& evt);

private:
    Color m_color;

DECLARE_EVENT_TABLE();
};




#endif // Include once wrapper
