/*
  Project:      POVColor
  File:         file.h
  Purpose:      File object for holding items
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __POVCOLOR_FILE_H__
#define __POVCOLOR_FILE_H__


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>

#include "item.h"


// Forward declarations
class WXDLLEXPORT wxWindow;
class WXDLLEXPORT wxFileHistory;


// File - A file object for holding items
//-----------------------------------------------------------------------------
class File
{
public:
    File();
    File(const File& copy);
  
    ~File();
  
    // Is the file modified
    bool IsModified() const;
    void SetModified(bool modified = true);
  
    // Items in the file
    size_t GetCount() const;    
  
    // Item by index
    PovItem& operator[](size_t k);
    const PovItem& operator[](size_t k) const;
  
    // Add an item to the file (takes ownership also)
    // If any other item with the same name is enabled
    // it will be disabled
    void AddItem(PovItem* item);
  
    // Remove an item in the file
    void Remove(size_t item);
  
    // Is an item with a name enabled
    bool IsEnabled(const wxString& name) const;

    // Enable the given item.  All other items with the
    // same name will be disabled if needed
    void Enable(size_t item, bool enabled = true);

    // Sort the items
    void Sort(bool ascending = true);

    // Position the items
    void Move(size_t dest, size_t src);
  
    // Clear the file, name, and state, no prompt to save
    void Clear();
  
    // The filename
    const wxString& GetFileName() const;
  
    // Load or save with filename
    // m_fname may be passed to these functions and they may change
    // m_fname, so don't take it by reference
    // Otherwise, changing m_fname may also change passed reference,
    // which may be m_fname, and cause problems elsewhere
    bool Load(wxString fname);
    bool LoadCopy(wxString fname);
    bool Save(wxString fname);
    bool SaveCopy(wxString fname);
  
private:
    // No assign
    File& operator=(const File& copy);

    // These do not change m_fname
    bool LoadFromFile(const wxString& fname);
    bool SaveToFile(const wxString& fname);
  
    // File items
    PovItemPtrArray m_items;
  
    // File name
    wxString m_fname;
  
    // State
    bool m_modified;
};


#endif // Include once wrapper

