/*
  Project:      POVColor
  File:         gammadlg.h
  Purpose:      Gamma dialog
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __POVCOLOR_GAMMADLG_H__
#define __POVCOLOR_GAMMADLG_H__


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>
#include <wx/dialog.h>


// Forward declarations
class WXDLLIMPEXP_CORE wxCheckBox;
class WXDLLIMPEXP_CORE wxStaticText;
class WXDLLIMPEXP_CORE wxSlider;
class WXDLLIMPEXP_CORE wxSizerItem;
class WXDLLIMPEXP_CORE wxRect;
class WXDLLIMPEXP_CORE wxDC;
class WXDLLIMPEXP_CORE wxColour;


// GammaDialog - Dialog to specify monitor gamma
//-----------------------------------------------------------------------------
class GammaDialog : public wxDialog
{
public:
    // ctor/dtor (no default ctor)
    GammaDialog(wxWindow* parent);
    ~GammaDialog();
    
    // Events
    void OnInitDialog(wxInitDialogEvent& evt);
    void OnOK(wxCommandEvent& evt);
    void OnCalibrate(wxCommandEvent& evt);
    
    // Slider events
    void OnGammaChange(wxScrollEvent& evt);
    
    // Paint events
    void OnPaint(wxPaintEvent& evt);
    
private:
    // Create dialog items
    void CreateWidgets();
    
    // Draw an area
    void DrawAreas(wxDC &dc);
    void DrawArea(wxDC& dc, const wxRect& rc, const wxColour& outer, const wxColour& inner);
    
    // Check box
    wxCheckBox* m_gammaCheck;
    
    // Sliders
    wxSlider* m_gammaSlider;
    
    // Text
    wxStaticText* m_gammaText;
    
    // Areas
    wxSizerItem* m_grayArea;
    wxSizerItem* m_redArea;
    wxSizerItem* m_greenArea;
    wxSizerItem* m_blueArea;
    
DECLARE_EVENT_TABLE();
};


#endif // Include once header

