/*
  Project:      POVColor
  File:         item.cpp
  Purpose:      Item implementation
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>
#include <wx/dc.h>
#include <wx/intl.h>
#include <wx/settings.h>

#include "item.h"


// PovItem - Base item class for color or colormap
//-----------------------------------------------------------------------------

// Constructors
PovItem::PovItem() : m_enabled(true)
{
}

PovItem::PovItem(const PovItem& copy) : m_name(copy.m_name), m_enabled(copy.m_enabled)
{
}

// Destructor
PovItem::~PovItem()
{
}

// Assignment
PovItem& PovItem::operator =(const PovItem& rhs)
{
    if(this != &rhs)
    {
        m_name = rhs.m_name;
        m_enabled = rhs.m_enabled;
    }
    
    return *this;
}
  
// Is a name valid
bool PovItem::NameIsValid(const wxString& name)
{
    size_t pos, count;
    
    // Test name
    count = name.Len();
    if(count == 0)
        return false;
        
    for(pos = 0; pos < count; pos++)
    {
        wxChar c = name[pos];
        
        if((c >= wxT('a') && c <= wxT('z')) || (c >= wxT('A') && c <= wxT('Z')) ||
            c == wxT('_') || (pos > 0 && (c >= wxT('0') && c <= wxT('9'))))
        {
            continue;
        }
        else
        {
            return false;
        }
    }
        
    return true;
}
  
  
// Draw a bevel
void PovItem::DrawBevel(wxDC& dc, const wxRect& rect)
{
    wxPen light(wxSystemSettings::GetColour(wxSYS_COLOUR_3DHIGHLIGHT));
    wxPen dark(wxSystemSettings::GetColour(wxSYS_COLOUR_3DDKSHADOW));

    int x1, x2, y1, y2;
    x1 = rect.x - 1;
    x2 = rect.x + rect.width;
    y1 = rect.y - 1;
    y2 = rect.y + rect.height;

    dc.SetPen(dark);
    dc.DrawLine(x1, y1, x2, y1);
    dc.DrawLine(x1, y1, x1, y2);

    dc.SetPen(light);
    dc.DrawLine(x2, y1, x2, y2);
    dc.DrawLine(x1, y2, x2, y2);

    dc.SetPen(wxNullPen); 
} 
  
