/*
  Project:      POVColor
  File:         item.h
  Purpose:      A POVColor item
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __POVCOLOR_ITEM_H__
#define __POVCOLOR_ITEM_H__


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>
#include <wx/string.h>
#include <wx/bitmap.h>
#include <wx/dynarray.h>


// Forward declarations
class WXDLLIMPEXP_CORE wxWindow;
class WXDLLIMPEXP_CORE wxDC;
class WXDLLIMPEXP_CORE wxRect;

class PovInput;
class PovOutput;


// PovItem - Base item class for color or colormap
//-----------------------------------------------------------------------------
class PovItem
{
public:
    // Constructors
    PovItem();
    PovItem(const PovItem& copy);
        
    // Destructor
    virtual ~PovItem();
        
    // Assignment
    PovItem& operator =(const PovItem& rhs);

    // Name
    void SetName(const wxString& name) { m_name = name; }
    const wxString& GetName() const { return m_name; }
    
    static bool NameIsValid(const wxString& name);
    
    // State
    void Enable(bool enabled = true) { m_enabled = enabled; }
    bool IsEnabled() const { return m_enabled; }
        
    // Copy code to the clipboard
    // This is different from a normal copy that it should only copy the
    // heart of the item, the 'color rgb <...>' or '[...]\n[...]' parts 
    virtual void CopyCode() const = 0;
    
    // Clone an item
    virtual PovItem* Clone() const = 0;
        
    // Load
    virtual bool Load(PovInput& in) = 0;
    
    // Save
    virtual bool Save(PovOutput& out, long indent) const = 0;
    
    // Edit
    virtual bool Edit(wxWindow* parent) = 0;
    
    // Draw
    virtual void Draw(wxDC& dc, const wxRect& rect) const = 0;
    
    // Draw an icon
    virtual void DrawIcon(wxDC& dc, const wxRect& rect) const = 0;
    
    // Some static methods
    static void DrawBevel(wxDC& dc, const wxRect& rect);
    
private:
    wxString m_name;
    bool m_enabled;
};
  
// An array of item pointers
WX_DEFINE_ARRAY_PTR(PovItem*, PovItemPtrArray);
  
 

#endif // Include once wrapper


