/*
  Project:      POVColor
  File:         mainwnd.h
  Purpose:      Main window class
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __POVCOLOR_MAINWND_H__
#define __POVCOLOR_MAINWND_H__


// Requirements
//-----------------------------------------------------------------------------

// Inlcudes
#include "config.h"

#include <wx/defs.h>
#include <wx/frame.h>


// Forward declarations
class WXDLLEXPORT wxNotebook;
class WXDLLEXPORT wxMenu;
class WXDLLEXPORT wxFileHistory;

class View;


// MainWindow - main window for the program
//-----------------------------------------------------------------------------
class MainWindow : public wxFrame
{
public:
    // Constructor/Destructor
    MainWindow();
    ~MainWindow();
  
    // Events
    void OnFileNew(wxCommandEvent& evt);
    void OnFileOpen(wxCommandEvent& evt);
    void OnFileOpenCopy(wxCommandEvent& evt);
    void OnFileOpenRecent(wxCommandEvent& evt);
    void OnFileSave(wxCommandEvent& evt);
    void OnFileSaveAs(wxCommandEvent& evt);
    void OnFileSaveCopy(wxCommandEvent& evt);
    void OnFileClose(wxCommandEvent& evt);
    void OnFileExit(wxCommandEvent& evt);
    
    void OnEditCopy(wxCommandEvent& evt);
    void OnEditPaste(wxCommandEvent& evt);
    void OnEditEdit(wxCommandEvent& evt);
    void OnEditRename(wxCommandEvent& evt);
    void OnEditDelete(wxCommandEvent& evt);
    void OnEditCopyCode(wxCommandEvent& evt);
    void OnEditEnable(wxCommandEvent& evt);
    void OnEditDisable(wxCommandEvent& evt);
    void OnEditSort(wxCommandEvent& evt);
    void OnEditMove(wxCommandEvent& evt);    

    void OnItemNewColor(wxCommandEvent& evt);
    void OnItemNewMap(wxCommandEvent& evt);

    void OnViewOptions(wxCommandEvent& evt);
    void OnViewGamma(wxCommandEvent& evt);
    
    void OnHelpContents(wxCommandEvent& evt);
    void OnHelpAbout(wxCommandEvent& evt);
    
    void OnClose(wxCloseEvent& evt);

    bool OpenFile(const wxString& file, bool copy = false);

private:
    // No copy/assign
    MainWindow(const MainWindow& copy);
    MainWindow& operator=(const MainWindow& copy);

    void CreateWidgets();
    void NewFile();
    bool SaveFile(View* v, bool ask = false, bool copy = false);
    bool QueryClose(View* v);  
    bool CloseAllFiles();
    
    wxNotebook* m_notebook;
    wxFileHistory* m_history;

DECLARE_EVENT_TABLE();
};

#endif // Include once wrapper

