/*
  Project:      POVColor
  File:         output.h
  Purpose:      Write POV output
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __POVCOLOR_OUTPUT_H__
#define __POVCOLOR_OUTPUT_H__


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>
#include <wx/txtstrm.h>


// Forward declarations
class wxOutputStream;

class File;
class PovItem;


// PovOutput - Output for POVRay
//-----------------------------------------------------------------------------
class PovOutput
{
public:
    // ctor/dtor (no default ctor)
    PovOutput(wxOutputStream& stream, const wxString& fname = wxEmptyString,
        wxEOL mode = wxEOL_NATIVE);
    ~PovOutput();
  
    // Is the file ok
    wxStreamError GetLastError() const; 
    
    // Indent the output file
    void WriteIndent(long count);
    void WriteString(const wxString &string);
    
    // Save a file to the output
    // Do not use this with SaveItem
    bool SaveFile(File& file);
    
    // Save individual items to a text string
    // Do not use this with SaveFile
    bool SaveItem(const PovItem& item, bool extras = false);
  
private:
    // No copy/assign
    PovOutput(const PovOutput& copy);
    PovOutput& operator=(const PovOutput& copy);

    bool WriteHeader();
    wxString GenerateIncludeOnceID() const;
    bool WriteIncludeOnceOpen(const wxString &id);
    bool WriteIncludeOnceClose(const wxString &id);
    bool WriteViewIncludeStack();
    bool WriteItems(File &file);

    wxString m_fname;
    wxOutputStream& m_stream;
    wxTextOutputStream m_text;
};


#endif // Include once wrapper

