/*
  Project:      POVColor
  File:         view.h
  Purpose:      View object for a given file
  Author:       Brian Vanderburg II
  Copyright:    (C) 2007-2008 Brian Allen Vanderburg II

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef __POVCOLOR_VIEW_H__
#define __POVCOLOR_VIEW_H__


// Requirements
//-----------------------------------------------------------------------------

// Includes
#include "config.h"

#include <wx/defs.h>
#include <wx/panel.h>

#include "file.h"


// Forward declarations
class WXDLLEXPORT wxWindow;
class WXDLLEXPORT wxVListBox;


// View - The view class
//-----------------------------------------------------------------------------
class View : public wxPanel
{
public:
    // Constructor/destructors (no default)
    View(wxWindow* parent);
    ~View();
  
    // Create it
    bool Create(wxWindow* parent);
  
    // Load/Save
    bool Load(const wxString& fname);
    bool LoadCopy(const wxString& fname);
    bool Save(const wxString& fname);
    bool SaveCopy(const wxString& fname);
  
    // Filename
    wxString GetFileName() const;
    wxString GetDisplayName() const;
  
    // Modified or not
    bool IsModified() const;
  
    // Copy/Paste (copies to text clipboard)
    void CopyItems();
    void PasteItems();
  
    // Redraw
    enum
    {
        REDRAW_REFRESHONLY = -100,
        REDRAW_DESELECT = -1
    };
    void RedrawList(int sel = REDRAW_REFRESHONLY); // -100 means no change in selection
    void UpdateList(int sel = REDRAW_REFRESHONLY); // use -1 to deselect all
  
    // Item manipulation
    void NewColor();
    void NewMap();
  
    void DeleteItem();
    void RenameItem();
    void CopyCode();
    void EditItem();
    void EnableItem(bool enabled = true);
  
    void Sort(bool ascending = true);
    void MoveUp();
    void MoveDown();
  
    // Events
    void OnListItemActivate(wxCommandEvent& evt);
  
private:
    // No copy/assign
    View(const View& copy);
    View& operator=(const View& copy);

    // Create items
    void CreateWidgets();
  
    // Get a valid name
    bool GetValidName(wxString& name, bool force = false) const;
  
    // Parent window
    wxWindow* m_parent;
  
    // File object
    File m_file;
  
    // List items
    wxVListBox* m_list;
  
DECLARE_EVENT_TABLE();    
};


#endif // Include once wrapper
