# POVColor - Color and map editor for POV-Ray
# Copyright (C) 2007-2008 Brian Allen Vanderburg II
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
########################################################################


# Requirements
########################################################################
import os

import SCons.Errors

from tools import util

# SCons imports
Import('*')

# Linux and similar configuration
########################################################################

# Variables
#----------
defvars.Add('PREFIX', 'Install Prefix', '/usr/local')
defvars.UpdateSome(defenv, ['PREFIX'])


# Environment
#------------

# For installation, set appropriate umask
os.umask(0022)

# Prepare paths
if not os.path.isabs(defenv['PREFIX']):
    raise SCons.Errors.UserError('PREFIX must be absolute')
else:
    defenv['PREFIX'] = os.path.normpath(defenv['PREFIX'])

# Tools
defenv.Tool('gcc')
defenv.Tool('g++')
defenv.Tool('gnulink')

# Warnings
defenv.Append(CCFLAGS='-W -Wall')

# Optimizations
if not defenv['DEBUG']:
    defenv.Append(CCFLAGS='-O2 --fast-math')

# Generate debugging information, it can be stripped from a release
defenv.Append(CCFLAGS='-g')

# Other options needed
defenv.Append(CCFLAGS='-fno-strict-aliasing')



