# POVColor - Color and map editor for POV-Ray
# Copyright (C) 2007-2008 Brian Allen Vanderburg II
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
########################################################################


# Requirements
########################################################################
import os
import re


# Utitity information, etc
########################################################################

# Version checking
#-----------------

# Compare versions
# return 0 if same, < 0 if first is smaller, > 0 if first is greater
def VersionCompare(version1, version2):
    # Remove whitespace
    version1 = version1.strip()
    version2 = version2.strip()

    # Split on "."
    parts1 = version1.split(".")
    len1 = len(parts1)
    parts2 = version2.split(".")
    len2 = len(parts2)

    # Make same size
    if len1 < len2:
        parts1.extend(["0"] * (len2 - len1))
    elif len2 < len1:
        parts2.extend(["0"] * (len1 - len2))

    # Check them, treat each part as a number
    result = map(lambda a,b: int(a) - int(b), parts1, parts2)
    for i in result:
        if i != 0:
            return i

    return 0

# Check a version against a min and max
# return 0 if in range, < 0 if smaller than min, > 0 if greater than max
def VersionCheck(version, minVersion, maxVersion = None):
    # Check order if needed
    if maxVersion is not None:
        if VersionCompare(minVersion, maxVersion) > 0:
            (minVersion, maxVersion) = (maxVersion, minVersion)

    # Check the version
    if VersionCompare(version, minVersion) < 0:
        return -1

    if maxVersion is not None:
        if VersionCompare(version, maxVersion) > 0:
            return 1
    
    return 0


